<?php if (!defined('PmWiki')) exit();
#
# grease/grease.php
#
# PmWiki Grease skin code
# Copyright 2005-2006 Dominique Faure (dfaure@cpan.org)
#
# Based on 'Dive Into Greasemonkey' online book Copyright  2005 Mark Pilgrim
# (mark@diveintomark.org).
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# See http://www.pmwiki.org/wiki/Cookbook/GreaseSkin for info.
#
$RecipeInfo['GreaseSkin']['Version'] = '20070125';

global $SkinPartFmt, $WikiTitle;
SDVA($SkinPartFmt, array(
'wikititle' => "$WikiTitle - {\$Titlespaced}",
'title' => '{$Titlespaced}',
'subtitle' => '[[{$Groupspaced}]]&nbsp;&#8594;&nbsp;[[{$Namespaced}]]',
'actions' => '
* %item rel=nofollow accesskey=$[ak_search]%[[$[Search] -> $[{$SiteGroup}/Search]]]
* %item accesskey=$[ak_recentchanges]%[[$[Recent Changes] -> $[{$Group}/RecentChanges]]]
',
'pageactions' => '
* %item rel=nofollow%[[$[Printable View] -> {$PageUrl}?action=print]]
* %item rel=nofollow%[[$[Page History] -> {$PageUrl}?action=diff]]
* %item rel=nofollow%[[$[Edit Page] -> {$PageUrl}?action=edit]]
* %item rel=nofollow%[[$[Upload] -> {$PageUrl}?action=upload]]',
'sep' => '&middot;',
'sidebardisabled' => false,
'attachalias' => 'AttachClip:',
));
global $SkinPartStylesFmt;
SDVA($SkinPartStylesFmt, array(
'sidebardisabled' => '#maincontent { width: 99.5%; }',
));

# Ensure local CSS customization files are included after skin style
global $HTMLHeaderFmt;
$HTMLHeaderFmt[] = "<link rel='stylesheet' href='\$SkinDirUrl/grease.css' type='text/css'/>";

function RenderStyle($pagename, $params) {
  global $SkinPartFmt, $SkinPartStylesFmt;
  preg_match('/^\s*(!?)\s*(\S+)$/s', $params, $m);
  $bool = $SkinPartFmt[$m[2]];
  $style = $SkinPartStylesFmt[$m[2]];
  print ($m[1] ? ! $bool : $bool) ? "<style type='text/css'>$style</style>" : '';
}

function RenderPart($pagename, $part, $strip = '') {
  global $SkinPartFmt, $PCache;
  $n = "skin_$part";
  if(!isset($PCache[$pagename][$n])) {
    $t = MarkupToHTML($pagename, "<:block>{$SkinPartFmt[$part]}", array('escape' => 0));
    $PCache[$pagename][$n] = $strip ? preg_replace($strip, '', $t) : $t;
  }
  print $PCache[$pagename][$n];
}

function RenderTitle($pagename) {
  RenderPart($pagename, 'wikititle', "/(<[^>]+>|\r\n?|\n\r?)/");
}

function RenderActions($pagename, $actionslist) {
  global $SkinPartFmt, $PCache;
  if(!isset($PCache[$pagename]['skin_actions'])) {
    $pagelist = preg_split('/\s+/', $actionslist, -1, PREG_SPLIT_NO_EMPTY);
    foreach($pagelist as $p) {
      if (PageExists($p)) {
        $page = RetrieveAuthPage($p, 'read', false, READPAGE_CURRENT);
        $text = $page['text'];
        break;
      }
    }
    SDV($text, $SkinPartFmt['pageactions']);
    $text = preg_replace("/(\r\n|\n?\r)/", "\n", "$SkinPartFmt[actions]$text");
    $PCache[$pagename]['skin_actions'] =
      preg_replace('/(<\/li>)(?=\s*<li)/s', "$SkinPartFmt[sep] \\1",
                   MarkupToHTML($pagename, $text));
  }
  print $PCache[$pagename]['skin_actions'];
}

# print handling
global $action;
if ($action == 'print') {
  global $LinkPageExistsFmt, $GroupPrintHeaderFmt, 
    $GroupPrintFooterFmt, $GroupHeaderFmt, $GroupFooterFmt;

  $LinkPageExistsFmt = "<a class='wikilink' href='{\$PageUrl}?action=print'>\$LinkText</a>";
  LoadPageTemplate($pagename, "$SkinDir/print.tmpl");
  return;
}

# sidebar markup
Markup('nosidebar', 'directives', '/\\(:nosidebar:\\)/ei', "SetTmplDisplay('PageRightFmt',0)");
Markup('noright',   'directives', '/\\(:noright:\\)/ei',   "NoSideBar()");

function NoSideBar() {
  global $SkinPartFmt;
  $SkinPartFmt['sidebardisabled'] = true;
  SetTmplDisplay('PageRightFmt', 0);
}


# links decoration
global $EnableSkinLinkDecoration;
if(IsEnabled($EnableSkinLinkDecoration, 1)) {
  global $SkinPartFmt, $IMapLinkFmt, $LinkFunctions, $IMap;
  global $LinkPageCreateFmt, $LinkUploadCreateFmt, $UrlLinkFmt;

  $intermap = $SkinPartFmt['attachalias'];
  $IMapLinkFmt['Attach:'] = "<a class='attachlink' href='\$LinkUrl' rel='nofollow'>\$LinkText</a>";
  $IMapLinkFmt[$intermap] = "<a class='attachlink' href='\$LinkUrl' rel='nofollow'>\$LinkText</a><a class='createlink' href='\$LinkUpload'><img src='$SkinDirUrl/attachment.png' alt='' /></a>";
  $LinkFunctions[$intermap] = 'LinkUpload';
  $IMap[$intermap] = '$1';

  $LinkPageCreateFmt = "<a class='createlinktext' href='\$PageUrl?action=edit'>\$LinkText</a>";
  $LinkUploadCreateFmt = "<a class='createlinktext' href='\$LinkUpload'>\$LinkText</a><a class='createlink' href='\$LinkUpload'><img src='$SkinDirUrl/attachnew.png' alt='' /></a>";
#  $UrlLinkFmt =  "<span class='urllink'><a class='urllink' href='\$LinkUrl' rel='nofollow'>\$LinkText</a></span>";
}

# $StopWatch handling
function RenderStopWatch($pagename) {
  global $EnableStopWatch;

  if(function_exists('StopWatchHTML'))
    StopWatchHTML($pagename, $EnableStopWatch);
  else
    if($EnableStopWatch && function_exists('DisplayStopWatch'))
      print DisplayStopWatch();
}

# trails decoration
global $TrailFmt;
$TrailFmt = array(
  'head' => '&#8592; ',
  'tail' => ' &#8594;',
  'headB' => '&#8592; ',
  'tailB' => ' &#8594;',
  'sep' => ' &middot; ',
);
